@@ -75,7 +75,7 @@ popd
 install -m 755 $DC_SOURCE_DIR/doublecmd.sh       $DC_ROOT_DIR/
 
 # Make portable config file
-sed -i -e 's/<UseConfigInProgramDir>False/<UseConfigInProgramDir>True/' $DC_ROOT_DIR/doublecmd.xml
+touch $DC_ROOT_DIR/doublecmd.inf
 
 # Create archive
 tar -cJvf $PACK_DIR/doublecmd-$DC_VER.$LCL_PLATFORM.$CPU_TARGET.tar.xz doublecmd
